@@ -42,7 +42,8 @@
 #
 # @keyword file
 # @keyword IO
-#*/########################################################################### 
+# @keyword internal
+#*/###########################################################################
 setMethodS3("rsptex", "default", function(..., pdf=TRUE, force=FALSE, verbose=FALSE) {
   # - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
   # Validate arguments
@@ -86,7 +87,7 @@ setMethodS3("rsptex", "default", function(..., pdf=TRUE, force=FALSE, verbose=FA
   verbose && exit(verbose);
 
   invisible(pathname3);
-}) # rsptex()
+}, private=TRUE) # rsptex()
 
 
 ############################################################################
